@@ -1,11 +1,11 @@
 """Pydantic Mapping Configuration Data Model."""
-from typing import Dict, List, Optional
+from typing import Annotated, Dict, List, Optional
 
 from pydantic import Field, conlist
 
 from oteapi.models.genericconfig import GenericConfig
 
-SemanticTriple = conlist(str, min_items=3, max_items=3)
+SemanticTriple = Annotated[list, conlist(str, min_items=3, max_items=3)]
 
 
 class MappingConfig(GenericConfig):
@@ -21,7 +21,7 @@ class MappingConfig(GenericConfig):
             "given as local value/IRI-expansion-pairs."
         ),
     )
-    triples: Optional[List[SemanticTriple]] = Field(  # type: ignore[valid-type]
+    triples: Optional[List[SemanticTriple]] = Field(
         None,
         description="List of semantic triples given as (subject, predicate, object).",
     )
